# build
rm -rf dist && python -m build

# publish
python -m twine upload dist/* --verbose

pypi-AgEIcHlwaS5vcmcCJDRjMjQ2MjlkLTBmY2YtNDMzNC05NzZjLTQ3NmYzNWUzYzNjYwACKlszLCIyNDJmOGVkZi00NjZhLTRiZWQtYTRiYi0wYzdlODEyMTk1NWUiXQAABiD7eydVe3-KbRGFtOVx5lKYXCxfRpGYxqFtnndn2aUXcg